@@ -81,11 +81,6 @@ ss4m = function(N, mu, sigma, DEFF=1, conf=0.95, cve=0.05, rme=0.03, plot=FALSE)
     abline(v=n.rme,lty=3)
   }
   
-  msg <- cat('With the parameters of this function: N =', N, 'mu =', mu, 'sigma =', sigma, 'DEFF = ',
-             DEFF, 'conf =', conf, '.\n
-             The estimated sample size to obatin a maximun coefficient of variation of', 100*cve, '% is n=', ceiling(n.cve), '.
-             The estimated sample size to obatin a maximun margin of error of', 100*rme, '% is n=', ceiling(n.rme), '. \n \n')
-  
   result <- list(n.cve = ceiling(n.cve), n.rme = ceiling(n.rme))
   result 
 }
